@@ -136,7 +136,7 @@ void MrExp::Init(double *dmrexp)
 
 bool MrExp::DrawNug(unsigned int n, double **X, double **F, double *Z, 
 		    double *lambda, double **bmu, double **Vb, double tau2, 
-		    double itemp, void *state)
+		    double itemp, bool cart, void *state)
 {
   bool success = false;
   MrGp_Prior *gp_prior = (MrGp_Prior*) base_prior;
@@ -152,7 +152,7 @@ bool MrExp::DrawNug(unsigned int n, double **X, double **F, double *Z,
 		    Kchol_new, &log_det_K_new, &lambda_new, Vb_new, bmu_new, 
 		    gp_prior->get_b0(), gp_prior->get_Ti(), gp_prior->get_T(), 
 		    tau2, prior->NugAlpha(), prior->NugBeta(), gp_prior->s2Alpha(), 
-		    gp_prior->s2Beta(), (int) linear, itemp, state);
+		    gp_prior->s2Beta(), (int) linear, itemp, (int) cart, state);
   
   /* did we accept the draw? */
   if(nug_new != nug) { nug = nug_new; success = true; swap_new(Vb, bmu, lambda); }
@@ -232,7 +232,7 @@ void MrExp::Update(unsigned int n1, unsigned int n2, double **K, double **X,
 
 int MrExp::Draw(unsigned int n, double **F, double **X, double *Z, 
 	      double *lambda, double **bmu, double **Vb, double tau2, 
-	      double itemp, void *state)
+		double itemp, bool cart, void *state)
 {
   int success = 0;
   bool lin_new;
@@ -240,7 +240,7 @@ int MrExp::Draw(unsigned int n, double **F, double **X, double *Z,
 
   /* sometimes skip this Draw for linear models for speed */
   if(linear && runi(state) > 0.5) 
-    return DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, itemp, state);
+    return DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, itemp, cart, state);
 
   /* proppose linear or not */
   if(prior->Linear()) lin_new = true;
@@ -276,7 +276,7 @@ int MrExp::Draw(unsigned int n, double **F, double **X, double *Z,
 		    Ki_new, Kchol_new, &log_det_K_new, &lambda_new, Vb_new, bmu_new,  
 		    gp_prior->get_b0(), gp_prior->get_Ti(), gp_prior->get_T(), tau2, 
 		    nug, q_bak/q_fwd, ep->DAlpha(), ep->DBeta(), gp_prior->s2Alpha(), 
-		    gp_prior->s2Beta(), (int) lin_new, itemp, state);
+		    gp_prior->s2Beta(), (int) lin_new, itemp, (bool) cart, state);
   }
   
   /* did we accept the new draw? */
@@ -291,7 +291,7 @@ int MrExp::Draw(unsigned int n, double **F, double **X, double *Z,
   if(dreject >= REJECTMAX) return -2;
 
   /* draw nugget */
-  bool changed = DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, itemp, state);
+  bool changed = DrawNug(n, X, F, Z, lambda, bmu, Vb, tau2, itemp, cart, state);
   success = success || changed;
   
   return success;
